# Generated by roxygen2: do not edit by hand

S3method(getDaily,default)
S3method(getDaily,egret)
S3method(getInfo,default)
S3method(getInfo,egret)
S3method(getSurfaces,default)
S3method(getSurfaces,egret)
S3method(plot,egret)
S3method(print,egret)
export(WRTDSKalman)
export(as.egret)
export(bin_Qs)
export(blankTime)
export(boxConcMonth)
export(boxConcThree)
export(boxQTwice)
export(boxResidMonth)
export(calculateMonthlyResults)
export(censoredSegments)
export(checkStartEndDate)
export(checkSurfaceSpan)
export(cleanUp)
export(compressData)
export(concConst)
export(cumQdate)
export(dataOverview)
export(dateFormatCheck)
export(decimalDate)
export(decimalHighLow)
export(errorStats)
export(estCrossVal)
export(estDailyFromSurfaces)
export(estSurfaces)
export(fixSampleFrame)
export(flexFN)
export(flexPlotAddOn)
export(flowDuration)
export(fluxBiasMulti)
export(fluxBiasStat)
export(fluxConst)
export(generalAxis)
export(genericEGRETDotPlot)
export(getConcFluxFromSurface)
export(getDaily)
export(getInfo)
export(getSample)
export(getSample.default)
export(getSurfaceEstimates)
export(getSurfaces)
export(is.egret)
export(jitterSam)
export(logPretty1)
export(logPretty3)
export(makeAnnualSeries)
export(makeAugmentedSample)
export(makeDateInfo)
export(mergeReport)
export(modelEstimation)
export(monthInfo)
export(multiPlotDataOverview)
export(nCensoredVals)
export(nDischarge)
export(nObservations)
export(plot15)
export(plot1of15)
export(plotConcHist)
export(plotConcPred)
export(plotConcQ)
export(plotConcQSmooth)
export(plotConcTime)
export(plotConcTimeDaily)
export(plotConcTimeSmooth)
export(plotContours)
export(plotDiffContours)
export(plotFlowSingle)
export(plotFluxHist)
export(plotFluxPred)
export(plotFluxQ)
export(plotFluxTimeDaily)
export(plotFour)
export(plotFourStats)
export(plotMonthTrend)
export(plotQTimeDaily)
export(plotResidPred)
export(plotResidQ)
export(plotResidTime)
export(plotSDLogQ)
export(plotTimeSlice)
export(plotWRTDSKalman)
export(populateConcentrations)
export(populateDaily)
export(populateDailySamp)
export(populateDateColumns)
export(populateParameterINFO)
export(populateSampleColumns)
export(populateSiteINFO)
export(printFluxUnitCheatSheet)
export(printGroups)
export(printPairs)
export(printSeries)
export(printqUnitCheatSheet)
export(processQWData)
export(qConst)
export(randomSubset)
export(readDataFromFile)
export(readNWISDaily)
export(readNWISInfo)
export(readNWISSample)
export(readUserDaily)
export(readUserInfo)
export(readUserSample)
export(readWQPInfo)
export(readWQPSample)
export(removeDuplicates)
export(runGroups)
export(runPairs)
export(runSeries)
export(runSurvReg)
export(run_WRTDS)
export(saveResults)
export(selectDays)
export(setPA)
export(setSeasonLabel)
export(setSeasonLabelByUser)
export(setUpEstimation)
export(setupYears)
export(startEnd)
export(stitch)
export(surfaceIndex)
export(surfaceStartEnd)
export(tableChange)
export(tableChangeSingle)
export(tableFlowChange)
export(tableResults)
export(triCube)
export(yPretty)
exportClasses(concUnit)
exportClasses(fluxUnit)
exportClasses(monthLabel)
exportClasses(qUnit)
import(methods)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,boxplot)
importFrom(graphics,contour)
importFrom(graphics,filled.contour)
importFrom(graphics,grconvertX)
importFrom(graphics,grconvertY)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(graphics,title)
importFrom(stats,aggregate)
importFrom(stats,filter)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,reshape)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,URLencode)
importFrom(utils,read.delim)
importFrom(utils,tail)
importFrom(utils,write.table)
